@@ -29,7 +29,7 @@ class Spinach::Features::ProjectWiki < Spinach::FeatureSteps
     expect(page).to have_content "link test"
 
     click_link "link test"
-    expect(page).to have_content "Edit Page"
+    expect(page).to have_content "Create Page"
   end
 
   step 'I have an existing Wiki page' do
@@ -80,13 +80,9 @@ class Spinach::Features::ProjectWiki < Spinach::FeatureSteps
     expect(page).to have_content "Page was successfully deleted"
   end
 
-  step 'I click on the "Pages" button' do
-    click_on "Pages"
-  end
-
   step 'I should see the existing page in the pages list' do
     expect(page).to have_content current_user.name
-    expect(page).to have_content @page.title
+    expect(find('.wiki-pages')).to have_content @page.title.capitalize
   end
 
   step 'I have an existing Wiki page with images linked on page' do
@@ -125,7 +121,7 @@ class Spinach::Features::ProjectWiki < Spinach::FeatureSteps
   step 'I should see the new wiki page form' do
     expect(current_path).to match('wikis/image.jpg')
     expect(page).to have_content('New Wiki Page')
-    expect(page).to have_content('Edit Page')
+    expect(page).to have_content('Create Page')
   end
 
   step 'I create a New page with paths' do
@@ -142,8 +138,8 @@ class Spinach::Features::ProjectWiki < Spinach::FeatureSteps
   end
 
   step 'I edit the Wiki page with a path' do
-    expect(page).to have_content('three')
-    click_on 'three'
+    expect(find('.wiki-pages')).to have_content('Three')
+    click_on 'Three'
     expect(find('.nav-text')).to have_content('Three')
     click_on 'Edit'
   end
@@ -157,7 +153,7 @@ class Spinach::Features::ProjectWiki < Spinach::FeatureSteps
   end
 
   step 'I view the page history of a Wiki page that has a path' do
-    click_on 'three'
+    click_on 'Three'
     click_on 'Page History'
   end
 
