@@ -7,8 +7,6 @@ describe Environment, models: true do
   it { is_expected.to belong_to(:project) }
   it { is_expected.to have_many(:deployments) }
 
-  it { is_expected.to delegate_method(:last_deployment).to(:deployments).as(:last) }
-
   it { is_expected.to delegate_method(:stop_action).to(:last_deployment) }
   it { is_expected.to delegate_method(:manual_actions).to(:last_deployment) }
 
@@ -22,6 +20,20 @@ describe Environment, models: true do
   it { is_expected.to validate_length_of(:external_url).is_at_most(255) }
   it { is_expected.to validate_uniqueness_of(:external_url).scoped_to(:project_id) }
 
+  describe '.order_by_last_deployed_at' do
+    let(:project) { create(:project) }
+    let!(:environment1) { create(:environment, project: project) }
+    let!(:environment2) { create(:environment, project: project) }
+    let!(:environment3) { create(:environment, project: project) }
+    let!(:deployment1) { create(:deployment, environment: environment1) }
+    let!(:deployment2) { create(:deployment, environment: environment2) }
+    let!(:deployment3) { create(:deployment, environment: environment1) }
+
+    it 'returns the environments in order of having been last deployed' do
+      expect(project.environments.order_by_last_deployed_at.to_a).to eq([environment3, environment2, environment1])
+    end
+  end
+
   describe '#nullify_external_url' do
     it 'replaces a blank url with nil' do
       env = build(:environment, external_url: "")
@@ -32,7 +44,7 @@ describe Environment, models: true do
   end
 
   describe '#includes_commit?' do
-    let(:project) { create(:project) }
+    let(:project) { create(:project, :repository) }
 
     context 'without a last deployment' do
       it "returns false" do
@@ -81,7 +93,7 @@ describe Environment, models: true do
   end
 
   describe '#first_deployment_for' do
-    let(:project)       { create(:project) }
+    let(:project)       { create(:project, :repository) }
     let!(:deployment)   { create(:deployment, environment: environment, ref: commit.parent.id) }
     let!(:deployment1)  { create(:deployment, environment: environment, ref: commit.id) }
     let(:head_commit)   { project.commit }
@@ -112,8 +124,8 @@ describe Environment, models: true do
     end
   end
 
-  describe '#stoppable?' do
-    subject { environment.stoppable? }
+  describe '#stop_action?' do
+    subject { environment.stop_action? }
 
     context 'when no other actions' do
       it { is_expected.to be_falsey }
@@ -142,17 +154,39 @@ describe Environment, models: true do
     end
   end
 
-  describe '#stop!' do
+  describe '#stop_with_action!' do
     let(:user) { create(:user) }
 
-    subject { environment.stop!(user) }
+    subject { environment.stop_with_action!(user) }
 
     before do
-      expect(environment).to receive(:stoppable?).and_call_original
+      expect(environment).to receive(:available?).and_call_original
     end
 
     context 'when no other actions' do
-      it { is_expected.to be_nil }
+      context 'environment is available' do
+        before do
+          environment.update(state: :available)
+        end
+
+        it do
+          subject
+
+          expect(environment).to be_stopped
+        end
+      end
+
+      context 'environment is already stopped' do
+        before do
+          environment.update(state: :stopped)
+        end
+
+        it do
+          subject
+
+          expect(environment).to be_stopped
+        end
+      end
     end
 
     context 'when matching action is defined' do
@@ -288,6 +322,11 @@ describe Environment, models: true do
       "1-foo"                     => "env-1-foo" + SUFFIX,
       "1/foo"                     => "env-1-foo" + SUFFIX,
       "foo-"                      => "foo" + SUFFIX,
+      "foo--bar"                  => "foo-bar" + SUFFIX,
+      "foo**bar"                  => "foo-bar" + SUFFIX,
+      "*-foo"                     => "env-foo" + SUFFIX,
+      "staging-12345678-"         => "staging-12345678" + SUFFIX,
+      "staging-12345678-01234567" => "staging-12345678" + SUFFIX,
     }.each do |name, matcher|
       it "returns a slug matching #{matcher}, given #{name}" do
         slug = described_class.new(name: name).generate_slug
@@ -296,4 +335,33 @@ describe Environment, models: true do
       end
     end
   end
+
+  describe '#external_url_for' do
+    let(:source_path) { 'source/file.html' }
+    let(:sha) { RepoHelpers.sample_commit.id }
+
+    before do
+      environment.external_url = 'http://example.com'
+    end
+
+    context 'when the public path is not known' do
+      before do
+        allow(project).to receive(:public_path_for_source_path).with(source_path, sha).and_return(nil)
+      end
+
+      it 'returns nil' do
+        expect(environment.external_url_for(source_path, sha)).to be_nil
+      end
+    end
+
+    context 'when the public path is known' do
+      before do
+        allow(project).to receive(:public_path_for_source_path).with(source_path, sha).and_return('file.html')
+      end
+
+      it 'returns the full external URL' do
+        expect(environment.external_url_for(source_path, sha)).to eq('http://example.com/file.html')
+      end
+    end
+  end
 end
