@@ -23,21 +23,74 @@ describe Issue, models: true do
   end
 
   describe '#to_reference' do
-    let(:project) { build(:empty_project, name: 'sample-project') }
-    let(:issue) { build(:issue, iid: 1, project: project) }
+    let(:namespace) { build(:namespace, path: 'sample-namespace') }
+    let(:project)   { build(:empty_project, name: 'sample-project', namespace: namespace) }
+    let(:issue)     { build(:issue, iid: 1, project: project) }
+    let(:group)     { create(:group, name: 'Group', path: 'sample-group') }
 
-    it 'returns a String reference to the object' do
-      expect(issue.to_reference).to eq "#1"
+    context 'when nil argument' do
+      it 'returns issue id' do
+        expect(issue.to_reference).to eq "#1"
+      end
     end
 
-    it 'returns a String reference with the full path' do
-      expect(issue.to_reference(full: true)).to eq(project.path_with_namespace + '#1')
+    context 'when full is true' do
+      it 'returns complete path to the issue' do
+        expect(issue.to_reference(full: true)).to          eq 'sample-namespace/sample-project#1'
+        expect(issue.to_reference(project, full: true)).to eq 'sample-namespace/sample-project#1'
+        expect(issue.to_reference(group, full: true)).to   eq 'sample-namespace/sample-project#1'
+      end
+    end
+
+    context 'when same project argument' do
+      it 'returns issue id' do
+        expect(issue.to_reference(project)).to eq("#1")
+      end
+    end
+
+    context 'when cross namespace project argument' do
+      let(:another_namespace_project) { create(:empty_project, name: 'another-project') }
+
+      it 'returns complete path to the issue' do
+        expect(issue.to_reference(another_namespace_project)).to eq 'sample-namespace/sample-project#1'
+      end
     end
 
     it 'supports a cross-project reference' do
-      another_project = build(:project, name: 'another-project', namespace: project.namespace)
+      another_project = build(:empty_project, name: 'another-project', namespace: project.namespace)
       expect(issue.to_reference(another_project)).to eq "sample-project#1"
     end
+
+    context 'when same namespace / cross-project argument' do
+      let(:another_project) { create(:empty_project, namespace: namespace) }
+
+      it 'returns path to the issue with the project name' do
+        expect(issue.to_reference(another_project)).to eq 'sample-project#1'
+      end
+    end
+
+    context 'when different namespace / cross-project argument' do
+      let(:another_namespace) { create(:namespace, path: 'another-namespace') }
+      let(:another_project)   { create(:empty_project, path: 'another-project', namespace: another_namespace) }
+
+      it 'returns full path to the issue' do
+        expect(issue.to_reference(another_project)).to eq 'sample-namespace/sample-project#1'
+      end
+    end
+
+    context 'when argument is a namespace' do
+      context 'with same project path' do
+        it 'returns path to the issue with the project name' do
+          expect(issue.to_reference(namespace)).to eq 'sample-project#1'
+        end
+      end
+
+      context 'with different project path' do
+        it 'returns full path to the issue' do
+          expect(issue.to_reference(group)).to eq 'sample-namespace/sample-project#1'
+        end
+      end
+    end
   end
 
   describe '#is_being_reassigned?' do
@@ -60,9 +113,9 @@ describe Issue, models: true do
   end
 
   describe '#closed_by_merge_requests' do
-    let(:project) { create(:project) }
-    let(:issue)   { create(:issue, project: project, state: "opened")}
-    let(:closed_issue) { build(:issue, project: project, state: "closed")}
+    let(:project) { create(:project, :repository) }
+    let(:issue) { create(:issue, project: project)}
+    let(:closed_issue) { build(:issue, :closed, project: project)}
 
     let(:mr) do
       opts = {
@@ -104,7 +157,7 @@ describe Issue, models: true do
 
   describe '#referenced_merge_requests' do
     it 'returns the referenced merge requests' do
-      project = create(:project, :public)
+      project = create(:empty_project, :public)
 
       mr1 = create(:merge_request,
                    source_project: project,
@@ -137,7 +190,7 @@ describe Issue, models: true do
     end
 
     context 'user is reporter in project issue belongs to' do
-      let(:project) { create(:project) }
+      let(:project) { create(:empty_project) }
       let(:issue) { create(:issue, project: project) }
 
       before { project.team << [user, :reporter] }
@@ -151,7 +204,7 @@ describe Issue, models: true do
 
       context 'checking destination project also' do
         subject { issue.can_move?(user, to_project) }
-        let(:to_project) { create(:project) }
+        let(:to_project) { create(:empty_project) }
 
         context 'destination project allowed' do
           before { to_project.team << [user, :reporter] }
@@ -217,7 +270,7 @@ describe Issue, models: true do
   end
 
   it_behaves_like 'an editable mentionable' do
-    subject { create(:issue) }
+    subject { create(:issue, project: create(:project, :repository)) }
 
     let(:backref_text) { "issue #{subject.to_reference}" }
     let(:set_mentionable_text) { ->(txt){ subject.description = txt } }
@@ -246,7 +299,7 @@ describe Issue, models: true do
 
   describe '#participants' do
     context 'using a public project' do
-      let(:project) { create(:project, :public) }
+      let(:project) { create(:empty_project, :public) }
       let(:issue) { create(:issue, project: project) }
 
       let!(:note1) do
@@ -268,7 +321,7 @@ describe Issue, models: true do
 
     context 'using a private project' do
       it 'does not include mentioned users that do not have access to the project' do
-        project = create(:project)
+        project = create(:empty_project)
         user = create(:user)
         issue = create(:issue, project: project)
 
